@@ -56,6 +56,7 @@ import jwt
 import requests
 import urllib3
 
+import github.Event
 import github.Gist
 import github.GithubObject
 import github.License
@@ -113,6 +114,7 @@ class Github(object):
         :param client_secret: string
         :param user_agent: string
         :param per_page: int
+        :param api_preview: bool
         :param verify: boolean or string
         :param retry: int or urllib3.util.retry.Retry object
         """
@@ -235,6 +237,16 @@ class Github(object):
             github.License.License, self.__requester, "/licenses", url_parameters
         )
 
+    def get_events(self):
+        """
+        :calls: `GET /events <https://developer.github.com/v3/activity/events/#list-public-events>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Event.Event`
+        """
+
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event, self.__requester, "/events", None
+        )
+
     def get_user(self, login=github.GithubObject.NotSet):
         """
         :calls: `GET /users/:user <http://developer.github.com/v3/users>`_ or `GET /user <http://developer.github.com/v3/users>`_
@@ -705,7 +717,7 @@ class Github(object):
     def create_from_raw_data(self, klass, raw_data, headers={}):
         """
         Creates an object from raw_data previously obtained by :attr:`github.GithubObject.GithubObject.raw_data`,
-        and optionaly headers previously obtained by :attr:`github.GithubObject.GithubObject.raw_headers`.
+        and optionally headers previously obtained by :attr:`github.GithubObject.GithubObject.raw_headers`.
 
         :param klass: the class of the object to create
         :param raw_data: dict
@@ -717,7 +729,7 @@ class Github(object):
     def dump(self, obj, file, protocol=0):
         """
         Dumps (pickles) a PyGithub object to a file-like object.
-        Some effort is made to not pickle sensitive informations like the Github credentials used in the :class:`Github` instance.
+        Some effort is made to not pickle sensitive information like the Github credentials used in the :class:`Github` instance.
         But NO EFFORT is made to remove sensitive information from the object's attributes.
 
         :param obj: the object to pickle
@@ -768,7 +780,7 @@ class GithubIntegration(object):
         The expiration can be extended beyond this, to a maximum of 600 seconds.
 
         :param expiration: int
-        :return:
+        :return string:
         """
         now = int(time.time())
         payload = {"iat": now, "exp": now + expiration, "iss": self.integration_id}
